@@ -853,6 +853,9 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
     return aFile;
 
 //@line 903 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+
+  // Remove leading dots
+  aFile = aFile.replace(/^\.+/, "");
       
   // Fix up the file name we're saving to to include the default extension
   var i = aFile.lastIndexOf(".");
